You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by sb...@apache.org on 2015/08/21 08:38:10 UTC

[38/44] incubator-ignite git commit: ignite-1258: modified documentation

ignite-1258: modified documentation


Project: http://git-wip-us.apache.org/repos/asf/incubator-ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-ignite/commit/e751a8ff
Tree: http://git-wip-us.apache.org/repos/asf/incubator-ignite/tree/e751a8ff
Diff: http://git-wip-us.apache.org/repos/asf/incubator-ignite/diff/e751a8ff

Branch: refs/heads/ignite-1258
Commit: e751a8ff3b63a52e5a573a0185fe6d629dd8a0ea
Parents: 7a25e9e
Author: Denis Magda <dm...@gridgain.com>
Authored: Thu Aug 20 13:46:08 2015 +0300
Committer: Denis Magda <dm...@gridgain.com>
Committed: Thu Aug 20 13:46:08 2015 +0300

----------------------------------------------------------------------
 .../java/org/apache/ignite/IgnitePortables.java | 44 +++++++-------
 .../portable/GridPortableMarshaller.java        |  2 +-
 .../internal/portable/PortableBuilderEnum.java  |  2 +-
 .../internal/portable/PortableBuilderImpl.java  |  2 +-
 .../portable/PortableBuilderReader.java         |  2 +-
 .../portable/PortableEnumArrayLazyValue.java    |  2 +-
 .../portable/PortableObjectArrayLazyValue.java  |  2 +-
 .../internal/portable/PortableObjectImpl.java   |  2 +-
 .../portable/PortableObjectOffheapImpl.java     |  2 +-
 .../marshaller/portable/PortableMarshaller.java |  5 +-
 .../apache/ignite/portable/PortableBuilder.java | 21 +++----
 .../ignite/portable/PortableIdMapper.java       | 29 ++++++----
 .../portable/PortableInvalidClassException.java | 20 +++++--
 .../ignite/portable/PortableMarshalAware.java   | 20 +++++--
 .../ignite/portable/PortableMetadata.java       | 26 ++++++---
 .../apache/ignite/portable/PortableObject.java  | 61 +++++++++++---------
 .../portable/PortableProtocolVersion.java       | 21 +++++--
 .../ignite/portable/PortableRawReader.java      | 20 +++++--
 .../ignite/portable/PortableRawWriter.java      | 20 +++++--
 .../apache/ignite/portable/PortableReader.java  | 20 +++++--
 .../ignite/portable/PortableSerializer.java     | 22 +++++--
 .../portable/PortableTypeConfiguration.java     | 30 ++++++----
 .../apache/ignite/portable/PortableWriter.java  | 20 +++++--
 .../GridPortableBuilderAdditionalSelfTest.java  |  6 +-
 24 files changed, 250 insertions(+), 151 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/IgnitePortables.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/IgnitePortables.java b/modules/core/src/main/java/org/apache/ignite/IgnitePortables.java
index efb6e6a..8bdc94a 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgnitePortables.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgnitePortables.java
@@ -50,28 +50,26 @@ import java.util.Date;
  * (assuming that class definitions are present in the classpath).
  * <p>
  * To work with the portable format directly, user should create a special cache projection
- * using {@link IgniteInternalCache#keepPortable()} method and then retrieve individual fields as needed:
+ * using {@link IgniteCache#withKeepPortable()} method and then retrieve individual fields as needed:
  * <pre name=code class=java>
- * CacheProjection&lt;GridPortableObject.class, GridPortableObject.class&gt; prj = cache.keepPortable();
+ * IgniteCache&lt;PortableObject, PortableObject&gt; prj = cache.withKeepPortable();
  *
  * // Convert instance of MyKey to portable format.
- * // We could also use GridPortableBuilder to create
- * // the key in portable format directly.
- * GridPortableObject key = grid.portables().toPortable(new MyKey());
+ * // We could also use PortableBuilder to create the key in portable format directly.
+ * PortableObject key = grid.portables().toPortable(new MyKey());
  *
- * GridPortableObject val = prj.get(key);
+ * PortableObject val = prj.get(key);
  *
  * String field = val.field("myFieldName");
  * </pre>
  * Alternatively, if we have class definitions in the classpath, we may choose to work with deserialized
- * typed objects at all times. In this case we do incur the deserialization cost, however,
- * Ignite will only deserialize on the first access and will cache the deserialized object,
- * so it does not have to be deserialized again:
+ * typed objects at all times. In this case we do incur the deserialization cost. However, if
+ * {@link PortableMarshaller#isKeepDeserialized()} is {@code true} then Ignite will only deserialize on the first access
+ * and will cache the deserialized object, so it does not have to be deserialized again:
  * <pre name=code class=java>
- * CacheProjection&lt;MyKey.class, MyValue.class&gt; prj =
- *     cache.projection(MyKey.class, MyValue.class);
+ * IgniteCache&lt;MyKey.class, MyValue.class&gt; cache = grid.cache(null);
  *
- * MyValue val = prj.get(new MyKey());
+ * MyValue val = cache.get(new MyKey());
  *
  * // Normal java getter.
  * String fieldVal = val.getMyFieldName();
@@ -80,7 +78,7 @@ import java.util.Date;
  * and still wanted to work with binary portable format for values, then we would declare cache projection
  * as follows:
  * <pre name=code class=java>
- * CacheProjection&lt;Integer.class, GridPortableObject.class&gt; prj = cache.keepPortable();
+ * IgniteCache&lt;Integer.class, PortableObject&gt; prj = cache.withKeepPortable();
  * </pre>
  * <h1 class="header">Automatic Portable Types</h1>
  * Note that only portable classes are converted to {@link PortableObject} format. Following
@@ -109,14 +107,14 @@ import java.util.Date;
  * <h1 class="header">Building Portable Objects</h1>
  * Ignite comes with {@link PortableBuilder} which allows to build portable objects dynamically:
  * <pre name=code class=java>
- * GridPortableBuilder builder = Ignition.ignite().portables().builder();
+ * PortableBuilder builder = Ignition.ignite().portables().builder();
  *
  * builder.typeId("MyObject");
  *
  * builder.stringField("fieldA", "A");
  * build.intField("fieldB", "B");
  *
- * GridPortableObject portableObj = builder.build();
+ * PortableObject portableObj = builder.build();
  * </pre>
  * For the cases when class definition is present
  * in the class path, it is also possible to populate a standard POJO and then
@@ -127,15 +125,15 @@ import java.util.Date;
  * obj.setFieldA("A");
  * obj.setFieldB(123);
  *
- * GridPortableObject portableObj = Ignition.ignite().portables().toPortable(obj);
+ * PortableObject portableObj = Ignition.ignite().portables().toPortable(obj);
  * </pre>
  * NOTE: you don't need to convert typed objects to portable format before storing
  * them in cache, Ignite will do that automatically.
  * <h1 class="header">Portable Metadata</h1>
  * Even though Ignite portable protocol only works with hash codes for type and field names
  * to achieve better performance, Ignite provides metadata for all portable types which
- * can be queried ar runtime via any of the {@link IgnitePortables#metadata(Class) GridPortables.metadata(...)}
- * methods. Having metadata also allows for proper formatting of {@code GridPortableObject.toString()} method,
+ * can be queried ar runtime via any of the {@link IgnitePortables#metadata(Class)}
+ * methods. Having metadata also allows for proper formatting of {@link PortableObject#toString()} method,
  * even when portable objects are kept in binary format only, which may be necessary for audit reasons.
  * <h1 class="header">Dynamic Structure Changes</h1>
  * Since objects are always cached in the portable binary format, server does not need to
@@ -161,7 +159,7 @@ import java.util.Date;
  * ...
  * &lt;!-- Explicit portable objects configuration. --&gt;
  * &lt;property name="marshaller"&gt;
- *     &lt;bean class="org.gridgain.grid.marshaller.portable.PortableMarshaller"&gt;
+ *     &lt;bean class="org.apache.ignite.marshaller.portable.PortableMarshaller"&gt;
  *         &lt;property name="classNames"&gt;
  *             &lt;list&gt;
  *                 &lt;value&gt;my.package.for.portable.objects.*&lt;/value&gt;
@@ -200,7 +198,7 @@ import java.util.Date;
  *         ...
  *         &lt;property name="typeConfigurations"&gt;
  *             &lt;list&gt;
- *                 &lt;bean class="org.apache.ignite.portables.PortableTypeConfiguration"&gt;
+ *                 &lt;bean class="org.apache.ignite.portable.PortableTypeConfiguration"&gt;
  *                     &lt;property name="className" value="org.apache.ignite.examples.client.portable.EmployeeKey"/&gt;
  *                     &lt;property name="affinityKeyFieldName" value="organizationId"/&gt;
  *                 &lt;/bean&gt;
@@ -214,19 +212,19 @@ import java.util.Date;
  * Serialization and deserialization works out-of-the-box in Ignite. However, you can provide your own custom
  * serialization logic by optionally implementing {@link PortableMarshalAware} interface, like so:
  * <pre name=code class=java>
- * public class Address implements GridPortableMarshalAware {
+ * public class Address implements PortableMarshalAware {
  *     private String street;
  *     private int zip;
  *
  *     // Empty constructor required for portable deserialization.
  *     public Address() {}
  *
- *     &#64;Override public void writePortable(GridPortableWriter writer) throws GridPortableException {
+ *     &#64;Override public void writePortable(PortableWriter writer) throws PortableException {
  *         writer.writeString("street", street);
  *         writer.writeInt("zip", zip);
  *     }
  *
- *     &#64;Override public void readPortable(GridPortableReader reader) throws GridPortableException {
+ *     &#64;Override public void readPortable(PortableReader reader) throws PortableException {
  *         street = reader.readString("street");
  *         zip = reader.readInt("zip");
  *     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/internal/portable/GridPortableMarshaller.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/portable/GridPortableMarshaller.java b/modules/core/src/main/java/org/apache/ignite/internal/portable/GridPortableMarshaller.java
index a25c97e..2969261 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/portable/GridPortableMarshaller.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/portable/GridPortableMarshaller.java
@@ -291,7 +291,7 @@ public class GridPortableMarshaller {
      * @return Reader.
      */
     public PortableReaderExImpl reader(PortableInputStream in) {
-        // TODO: GG-10396 - Is class loader needed here?
+        // TODO: IGNITE-1272 - Is class loader needed here?
         return new PortableReaderExImpl(ctx, in, in.position(), null);
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableBuilderEnum.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableBuilderEnum.java b/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableBuilderEnum.java
index eec68a5..9d29669 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableBuilderEnum.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableBuilderEnum.java
@@ -55,7 +55,7 @@ public class PortableBuilderEnum implements PortableBuilderSerializationAware {
             Class cls;
 
             try {
-                // TODO: GG-10396 - Is class loader needed here?
+                // TODO: IGNITE-1272 - Is class loader needed here?
                 cls = U.forName(reader.readString(), null);
             }
             catch (ClassNotFoundException e) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableBuilderImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableBuilderImpl.java b/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableBuilderImpl.java
index d471748..26f1d25 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableBuilderImpl.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableBuilderImpl.java
@@ -134,7 +134,7 @@ public class PortableBuilderImpl implements PortableBuilder {
             Class cls;
 
             try {
-                // TODO: GG-10396 - Is class loader needed here?
+                // TODO: IGNITE-1272 - Is class loader needed here?
                 cls = U.forName(clsNameToWrite, null);
             }
             catch (ClassNotFoundException e) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableBuilderReader.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableBuilderReader.java b/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableBuilderReader.java
index 3854a52..3e0286f 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableBuilderReader.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableBuilderReader.java
@@ -56,7 +56,7 @@ class PortableBuilderReader {
         arr = objImpl.array();
         pos = objImpl.start();
 
-        // TODO: GG-10396 - Is class loader needed here?
+        // TODO: IGNITE-1272 - Is class loader needed here?
         reader = new PortableReaderExImpl(portableContext(), arr, pos, null);
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableEnumArrayLazyValue.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableEnumArrayLazyValue.java b/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableEnumArrayLazyValue.java
index 8d4c80a..7fa04e8 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableEnumArrayLazyValue.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableEnumArrayLazyValue.java
@@ -47,7 +47,7 @@ class PortableEnumArrayLazyValue extends PortableAbstractLazyValue {
             Class cls;
 
             try {
-                // TODO: GG-10396 - Is class loader needed here?
+                // TODO: IGNITE-1272 - Is class loader needed here?
                 cls = U.forName(reader.readString(), null);
             }
             catch (ClassNotFoundException e) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableObjectArrayLazyValue.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableObjectArrayLazyValue.java b/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableObjectArrayLazyValue.java
index d32cbb1..16038d9 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableObjectArrayLazyValue.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableObjectArrayLazyValue.java
@@ -47,7 +47,7 @@ class PortableObjectArrayLazyValue extends PortableAbstractLazyValue {
             Class cls;
 
             try {
-                // TODO: GG-10396 - Is class loader needed here?
+                // TODO: IGNITE-1272 - Is class loader needed here?
                 cls = U.forName(reader.readString(), null);
             }
             catch (ClassNotFoundException e) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableObjectImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableObjectImpl.java b/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableObjectImpl.java
index aa4cc0d..f3dfd50 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableObjectImpl.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableObjectImpl.java
@@ -255,7 +255,7 @@ public final class PortableObjectImpl extends PortableObjectEx implements Extern
         Object obj0 = obj;
 
         if (obj0 == null) {
-            // TODO: GG-10396 - Deserialize with proper class loader.
+            // TODO: IGNITE-1272 - Deserialize with proper class loader.
             PortableReaderExImpl reader = new PortableReaderExImpl(ctx, arr, start, null);
 
             obj0 = reader.deserialize();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableObjectOffheapImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableObjectOffheapImpl.java b/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableObjectOffheapImpl.java
index b58c1e3..40655ba 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableObjectOffheapImpl.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/portable/PortableObjectOffheapImpl.java
@@ -159,7 +159,7 @@ public class PortableObjectOffheapImpl extends PortableObjectEx implements Exter
     /** {@inheritDoc} */
     @SuppressWarnings("unchecked")
     @Nullable @Override public <T> T deserialize() throws PortableException {
-        // TODO: GG-10396 - Deserialize with proper class loader.
+        // TODO: IGNITE-1272 - Deserialize with proper class loader.
         PortableReaderExImpl reader = new PortableReaderExImpl(
             ctx,
             new PortableOffheapInputStream(ptr, size, false),

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/marshaller/portable/PortableMarshaller.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/marshaller/portable/PortableMarshaller.java b/modules/core/src/main/java/org/apache/ignite/marshaller/portable/PortableMarshaller.java
index fab7f61..2a17363 100644
--- a/modules/core/src/main/java/org/apache/ignite/marshaller/portable/PortableMarshaller.java
+++ b/modules/core/src/main/java/org/apache/ignite/marshaller/portable/PortableMarshaller.java
@@ -32,8 +32,7 @@ import java.util.*;
  * Implementation of {@link org.apache.ignite.marshaller.Marshaller} that lets to serialize and deserialize all objects
  * in the portable format.
  * <p>
- * {@code PortableMarshaller} is tested only on Java HotSpot VM on other VMs
- * it could yield unexpected results.
+ * {@code PortableMarshaller} is tested only on Java HotSpot VM on other VMs it could yield unexpected results.
  * <p>
  * <h1 class="header">Configuration</h1>
  * <h2 class="header">Mandatory</h2>
@@ -56,7 +55,7 @@ import java.util.*;
  * &lt;bean id="grid.custom.cfg" class="org.apache.ignite.configuration.IgniteConfiguration" singleton="true"&gt;
  *     ...
  *     &lt;property name="marshaller"&gt;
- *         &lt;bean class="org.gridgain.grid.marshaller.portable.PortableMarshaller"&gt;
+ *         &lt;bean class="org.apache.ignite.marshaller.portable.PortableMarshaller"&gt;
  *            ...
  *         &lt;/bean&gt;
  *     &lt;/property&gt;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/portable/PortableBuilder.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/portable/PortableBuilder.java b/modules/core/src/main/java/org/apache/ignite/portable/PortableBuilder.java
index f6058cb..a899c46 100644
--- a/modules/core/src/main/java/org/apache/ignite/portable/PortableBuilder.java
+++ b/modules/core/src/main/java/org/apache/ignite/portable/PortableBuilder.java
@@ -17,27 +17,28 @@
 
 package org.apache.ignite.portable;
 
+import org.apache.ignite.*;
+
 import org.jetbrains.annotations.*;
 
 /**
- * Portable object builder. Provides ability to build portable objects dynamically
- * without having class definitions.
+ * Portable object builder. Provides ability to build portable objects dynamically without having class definitions.
  * <p>
  * Here is an example of how a portable object can be built dynamically:
  * <pre name=code class=java>
- * GridPortableBuilder builder = Ignition.ignite().portables().builder("org.project.MyObject");
+ * PortableBuilder builder = Ignition.ignite().portables().builder("org.project.MyObject");
  *
  * builder.setField("fieldA", "A");
  * builder.setField("fieldB", "B");
  *
- * GridPortableObject portableObj = builder.build();
+ * PortableObject portableObj = builder.build();
  * </pre>
  *
  * <p>
  * Also builder can be initialized by existing portable object. This allows changing some fields without affecting
  * other fields.
  * <pre name=code class=java>
- * GridPortableBuilder builder = Ignition.ignite().portables().builder(person);
+ * PortableBuilder builder = Ignition.ignite().portables().builder(person);
  *
  * builder.setField("name", "John");
  *
@@ -50,8 +51,8 @@ import org.jetbrains.annotations.*;
  * for example:
  *
  * <pre name=code class=java>
- * GridPortableBuilder personBuilder = grid.portables().createBuilder(personPortableObj);
- * GridPortableBuilder addressBuilder = personBuilder.setField("address");
+ * PortableBuilder personBuilder = grid.portables().createBuilder(personPortableObj);
+ * PortableBuilder addressBuilder = personBuilder.setField("address");
  *
  * addressBuilder.setField("city", "New York");
  *
@@ -61,9 +62,9 @@ import org.jetbrains.annotations.*;
  * String city = personPortableObj.getField("address").getField("city");
  * </pre>
  *
- * @see GridPortables#builder(int)
- * @see GridPortables#builder(String)
- * @see GridPortables#builder(PortableObject)
+ * @see IgnitePortables#builder(int)
+ * @see IgnitePortables#builder(String)
+ * @see IgnitePortables#builder(PortableObject)
  */
 public interface PortableBuilder {
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/portable/PortableIdMapper.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/portable/PortableIdMapper.java b/modules/core/src/main/java/org/apache/ignite/portable/PortableIdMapper.java
index 96452cd..9502a86 100644
--- a/modules/core/src/main/java/org/apache/ignite/portable/PortableIdMapper.java
+++ b/modules/core/src/main/java/org/apache/ignite/portable/PortableIdMapper.java
@@ -1,14 +1,24 @@
 /*
- *  Copyright (C) GridGain Systems. All Rights Reserved.
- *  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.ignite.portable;
 
+import org.apache.ignite.marshaller.portable.*;
+
 /**
  * Type and field ID mapper for portable objects. Ignite never writes full
  * strings for field or type names. Instead, for performance reasons, Ignite
@@ -16,12 +26,11 @@ package org.apache.ignite.portable;
  * hash code conflicts for the type names or the field names
  * within the same type are virtually non-existent and, to gain performance, it is safe
  * to work with hash codes. For the cases when hash codes for different types or fields
- * actually do collide {@code GridPortableIdMapper} allows to override the automatically
+ * actually do collide {@code PortableIdMapper} allows to override the automatically
  * generated hash code IDs for the type and field names.
  * <p>
- * Portable ID mapper can be configured for all portable objects via
- * {@link org.apache.ignite.marshaller.portable.PortableMarshaller#getIdMapper()} method, or for a specific
- * portable type via {@link PortableTypeConfiguration#getIdMapper()} method.
+ * Portable ID mapper can be configured for all portable objects via {@link PortableMarshaller#getIdMapper()} method,
+ * or for a specific portable type via {@link PortableTypeConfiguration#getIdMapper()} method.
  */
 public interface PortableIdMapper {
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/portable/PortableInvalidClassException.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/portable/PortableInvalidClassException.java b/modules/core/src/main/java/org/apache/ignite/portable/PortableInvalidClassException.java
index 152c0fd..533d453 100644
--- a/modules/core/src/main/java/org/apache/ignite/portable/PortableInvalidClassException.java
+++ b/modules/core/src/main/java/org/apache/ignite/portable/PortableInvalidClassException.java
@@ -1,10 +1,18 @@
 /*
- *  Copyright (C) GridGain Systems. All Rights Reserved.
- *  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.ignite.portable;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/portable/PortableMarshalAware.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/portable/PortableMarshalAware.java b/modules/core/src/main/java/org/apache/ignite/portable/PortableMarshalAware.java
index 031dc59..3ae2bd7 100644
--- a/modules/core/src/main/java/org/apache/ignite/portable/PortableMarshalAware.java
+++ b/modules/core/src/main/java/org/apache/ignite/portable/PortableMarshalAware.java
@@ -1,10 +1,18 @@
 /*
- *  Copyright (C) GridGain Systems. All Rights Reserved.
- *  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.ignite.portable;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/portable/PortableMetadata.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/portable/PortableMetadata.java b/modules/core/src/main/java/org/apache/ignite/portable/PortableMetadata.java
index cb4943e..9231cd9 100644
--- a/modules/core/src/main/java/org/apache/ignite/portable/PortableMetadata.java
+++ b/modules/core/src/main/java/org/apache/ignite/portable/PortableMetadata.java
@@ -1,22 +1,32 @@
 /*
- *  Copyright (C) GridGain Systems. All Rights Reserved.
- *  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.ignite.portable;
 
+import org.apache.ignite.*;
+
 import org.jetbrains.annotations.*;
 
 import java.util.*;
 
 /**
  * Portable type meta data. Metadata for portable types can be accessed from any of the
- * {@link GridPortables#metadata(String) GridPortables.metadata(...)} methods.
- * Having metadata also allows for proper formatting of {@code GridPortableObject.toString()} method,
+ * {@link IgnitePortables#metadata(String)} methods.
+ * Having metadata also allows for proper formatting of {@link PortableObject#toString()} method,
  * even when portable objects are kept in binary format only, which may be necessary for audit reasons.
  */
 public interface PortableMetadata {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/portable/PortableObject.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/portable/PortableProtocolVersion.java b/modules/core/src/main/java/org/apache/ignite/portable/PortableProtocolVersion.java
index 1b30471..5764560 100644
--- a/modules/core/src/main/java/org/apache/ignite/portable/PortableProtocolVersion.java
+++ b/modules/core/src/main/java/org/apache/ignite/portable/PortableProtocolVersion.java
@@ -1,9 +1,18 @@
-/* Copyright (C) GridGain Systems. All Rights Reserved.
- *  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.ignite.portable;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/portable/PortableRawReader.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/portable/PortableRawReader.java b/modules/core/src/main/java/org/apache/ignite/portable/PortableRawReader.java
index 7bb6668..93e2356 100644
--- a/modules/core/src/main/java/org/apache/ignite/portable/PortableRawReader.java
+++ b/modules/core/src/main/java/org/apache/ignite/portable/PortableRawReader.java
@@ -1,10 +1,18 @@
 /*
- *  Copyright (C) GridGain Systems. All Rights Reserved.
- *  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.ignite.portable;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/portable/PortableRawWriter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/portable/PortableRawWriter.java b/modules/core/src/main/java/org/apache/ignite/portable/PortableRawWriter.java
index 9dd74bc..e6efee5 100644
--- a/modules/core/src/main/java/org/apache/ignite/portable/PortableRawWriter.java
+++ b/modules/core/src/main/java/org/apache/ignite/portable/PortableRawWriter.java
@@ -1,10 +1,18 @@
 /*
- *  Copyright (C) GridGain Systems. All Rights Reserved.
- *  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.ignite.portable;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/portable/PortableReader.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/portable/PortableReader.java b/modules/core/src/main/java/org/apache/ignite/portable/PortableReader.java
index 9104f8d..25c2f6b 100644
--- a/modules/core/src/main/java/org/apache/ignite/portable/PortableReader.java
+++ b/modules/core/src/main/java/org/apache/ignite/portable/PortableReader.java
@@ -1,10 +1,18 @@
 /*
- *  Copyright (C) GridGain Systems. All Rights Reserved.
- *  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.ignite.portable;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/portable/PortableSerializer.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/portable/PortableSerializer.java b/modules/core/src/main/java/org/apache/ignite/portable/PortableSerializer.java
index 86e6a8b..54b0937 100644
--- a/modules/core/src/main/java/org/apache/ignite/portable/PortableSerializer.java
+++ b/modules/core/src/main/java/org/apache/ignite/portable/PortableSerializer.java
@@ -1,14 +1,24 @@
 /*
- *  Copyright (C) GridGain Systems. All Rights Reserved.
- *  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.ignite.portable;
 
+import org.apache.ignite.marshaller.portable.*;
+
 /**
  * Interface that allows to implement custom serialization logic for portable objects.
  * Can be used instead of {@link PortableMarshalAware} in case if the class

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/portable/PortableTypeConfiguration.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/portable/PortableTypeConfiguration.java b/modules/core/src/main/java/org/apache/ignite/portable/PortableTypeConfiguration.java
index 81e9219..b221298 100644
--- a/modules/core/src/main/java/org/apache/ignite/portable/PortableTypeConfiguration.java
+++ b/modules/core/src/main/java/org/apache/ignite/portable/PortableTypeConfiguration.java
@@ -1,15 +1,24 @@
 /*
- *  Copyright (C) GridGain Systems. All Rights Reserved.
- *  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.ignite.portable;
 
 import org.apache.ignite.internal.util.typedef.internal.*;
+import org.apache.ignite.marshaller.portable.*;
 
 import java.sql.*;
 import java.util.*;
@@ -17,12 +26,11 @@ import java.util.*;
 /**
  * Defines configuration properties for a specific portable type. Providing per-type
  * configuration is optional, as it is generally enough, and also optional, to provide global portable
- * configuration using {@link org.gridgain.grid.marshaller.portable.PortableMarshaller#setClassNames(Collection)}.
+ * configuration using {@link PortableMarshaller#setClassNames(Collection)}.
  * However, this class allows you to change configuration properties for a specific
  * portable type without affecting configuration for other portable types.
  * <p>
- * Per-type portable configuration can be specified in
- * {@link org.gridgain.grid.marshaller.portable.PortableMarshaller#getTypeConfigurations()} method.
+ * Per-type portable configuration can be specified in {@link PortableMarshaller#getTypeConfigurations()} method.
  */
 public class PortableTypeConfiguration {
     /** Class name. */
@@ -131,7 +139,7 @@ public class PortableTypeConfiguration {
 
     /**
      * Defines whether meta data is collected for this type. If provided, this value will override
-     * {@link org.gridgain.grid.marshaller.portable.PortableMarshaller#isMetaDataEnabled()} property.
+     * {@link PortableMarshaller#isMetaDataEnabled()} property.
      *
      * @return Whether meta data is collected.
      */
@@ -148,7 +156,7 @@ public class PortableTypeConfiguration {
 
     /**
      * Defines whether {@link PortableObject} should cache deserialized instance. If provided,
-     * this value will override {@link org.gridgain.grid.marshaller.portable.PortableMarshaller#isKeepDeserialized()}
+     * this value will override {@link PortableMarshaller#isKeepDeserialized()}
      * property.
      *
      * @return Whether deserialized value is kept.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/portable/PortableWriter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/portable/PortableWriter.java b/modules/core/src/main/java/org/apache/ignite/portable/PortableWriter.java
index c87dfd3..36fa608 100644
--- a/modules/core/src/main/java/org/apache/ignite/portable/PortableWriter.java
+++ b/modules/core/src/main/java/org/apache/ignite/portable/PortableWriter.java
@@ -1,10 +1,18 @@
 /*
- *  Copyright (C) GridGain Systems. All Rights Reserved.
- *  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.ignite.portable;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/test/java/org/apache/ignite/internal/portable/GridPortableBuilderAdditionalSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/apache/ignite/internal/portable/GridPortableBuilderAdditionalSelfTest.java b/modules/core/src/test/java/org/apache/ignite/internal/portable/GridPortableBuilderAdditionalSelfTest.java
index 1d7e7e7..1a41a4d 100644
--- a/modules/core/src/test/java/org/apache/ignite/internal/portable/GridPortableBuilderAdditionalSelfTest.java
+++ b/modules/core/src/test/java/org/apache/ignite/internal/portable/GridPortableBuilderAdditionalSelfTest.java
@@ -233,7 +233,7 @@ public class GridPortableBuilderAdditionalSelfTest extends GridCommonAbstractTes
      *
      */
     public void testModifyObjectArray() {
-        fail("http://atlassian.gridgain.com/jira/browse/GG-10170");
+        fail("https://issues.apache.org/jira/browse/IGNITE-1273");
 
         TestObjectContainer obj = new TestObjectContainer();
         obj.foo = new Object[]{"a"};
@@ -930,7 +930,7 @@ public class GridPortableBuilderAdditionalSelfTest extends GridCommonAbstractTes
      *
      */
     public void testCyclicArrays() {
-        fail("http://atlassian.gridgain.com/jira/browse/GG-10170");
+        fail("https://issues.apache.org/jira/browse/IGNITE-1273");
 
         TestObjectContainer obj = new TestObjectContainer();
 
@@ -953,7 +953,7 @@ public class GridPortableBuilderAdditionalSelfTest extends GridCommonAbstractTes
      */
     @SuppressWarnings("TypeMayBeWeakened")
     public void testCyclicArrayList() {
-        fail("http://atlassian.gridgain.com/jira/browse/GG-10170");
+        fail("https://issues.apache.org/jira/browse/IGNITE-1273");
         TestObjectContainer obj = new TestObjectContainer();
 
         List<Object> arr1 = new ArrayList<>();
diff --git a/modules/core/src/main/java/org/apache/ignite/portable/PortableObject.java b/modules/core/src/main/java/org/apache/ignite/portable/PortableObject.java
index 080abfd..b62b675 100644
--- a/modules/core/src/main/java/org/apache/ignite/portable/PortableObject.java
+++ b/modules/core/src/main/java/org/apache/ignite/portable/PortableObject.java
@@ -1,14 +1,25 @@
 /*
- *  Copyright (C) GridGain Systems. All Rights Reserved.
- *  _________        _____ __________________        _____
- *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
- *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
- *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
- *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.ignite.portable;
 
+import org.apache.ignite.*;
+import org.apache.ignite.marshaller.portable.*;
+
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -23,17 +34,15 @@ import java.util.*;
  * <b>NOTE:</b> user does not need to (and should not) implement this interface directly.
  * <p>
  * To work with the portable format directly, user should create a cache projection
- * over {@code GridPortableObject} class and then retrieve individual fields as needed:
+ * over {@code PortableObject} class and then retrieve individual fields as needed:
  * <pre name=code class=java>
- * CacheProjection&lt;GridPortableObject.class, GridPortableObject.class&gt; prj =
- *     cache.projection(GridPortableObject.class, GridPortableObject.class);
+ * IgniteCache&lt;PortableObject, PortableObject&gt; prj = cache.withKeepPortable();
  *
  * // Convert instance of MyKey to portable format.
- * // We could also use GridPortableBuilder to create
- * // the key in portable format directly.
- * GridPortableObject key = grid.portables().toPortable(new MyKey());
+ * // We could also use GridPortableBuilder to create the key in portable format directly.
+ * PortableObject key = grid.portables().toPortable(new MyKey());
  *
- * GridPortableObject val = prj.get(key);
+ * PortableObject val = prj.get(key);
  *
  * String field = val.field("myFieldName");
  * </pre>
@@ -41,10 +50,9 @@ import java.util.*;
  * the keys are concrete deserialized objects and the values are returned in portable
  * format, like so:
  * <pre name=code class=java>
- * CacheProjection&lt;MyKey.class, GridPortableObject.class&gt; prj =
- *     cache.projection(MyKey.class, GridPortableObject.class);
+ * IgniteCache&lt;MyKey, PortableObject&gt; prj = cache.withKeepPortable();
  *
- * GridPortableObject val = prj.get(new MyKey());
+ * PortableObject val = prj.get(new MyKey());
  *
  * String field = val.field("myFieldName");
  * </pre>
@@ -53,14 +61,13 @@ import java.util.*;
  * it may be very cheap to deserialize the keys, but not the values.
  * <p>
  * And finally, if we have class definitions in the classpath, we may choose to work with deserialized
  * typed objects at all times. In this case we do incur the deserialization cost, however,
  * Ignite will only deserialize on the first access and will cache the deserialized object,
  * so it does not have to be deserialized again:
  * <pre name=code class=java>
- * CacheProjection&lt;MyKey.class, MyValue.class&gt; prj =
- *     cache.projection(MyKey.class, MyValue.class);
+ * IgniteCache&lt;MyKey.class, MyValue.class&gt; cache = grid.cache(null);
  *
- * MyValue val = prj.get(new MyKey());
+ * MyValue val = cache.get(new MyKey());
  *
  * // Normal java getter.
  * String fieldVal = val.getMyFieldName();
@@ -84,12 +91,12 @@ import java.util.*;
  * <h1 class="header">Building Portable Objects</h1>
  * Ignite comes with {@link PortableBuilder} which allows to build portable objects dynamically:
  * <pre name=code class=java>
- * GridPortableBuilder builder = Ignition.ignite().portables().builder("org.project.MyObject");
+ * PortableBuilder builder = Ignition.ignite().portables().builder("org.project.MyObject");
  *
  * builder.setField("fieldA", "A");
  * builder.setField("fieldB", "B");
  *
- * GridPortableObject portableObj = builder.build();
+ * PortableObject portableObj = builder.build();
  * </pre>
  * For the cases when class definition is present
  * in the class path, it is also possible to populate a standard POJO and then
@@ -100,13 +107,13 @@ import java.util.*;
  * obj.setFieldA("A");
  * obj.setFieldB(123);
  *
- * GridPortableObject portableObj = Ignition.ignite().portables().toPortable(obj);
+ * PortableObject portableObj = Ignition.ignite().portables().toPortable(obj);
  * </pre>
  * <h1 class="header">Portable Metadata</h1>
  * Even though Ignite portable protocol only works with hash codes for type and field names
  * to achieve better performance, Ignite provides metadata for all portable types which
- * can be queried ar runtime via any of the {@link GridPortables#metadata(Class) GridPortables.metadata(...)}
- * methods. Having metadata also allows for proper formatting of {@code GridPortableObject.toString()} method,
+ * can be queried ar runtime via any of the {@link IgnitePortables#metadata(Class)}
+ * methods. Having metadata also allows for proper formatting of {@code PortableObject.toString()} method,
  * even when portable objects are kept in binary format only, which may be necessary for audit reasons.
  */
 public interface PortableObject extends Serializable, Cloneable {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/e751a8ff/modules/core/src/main/java/org/apache/ignite/portable/PortableProtocolVersion.java
----------------------------------------------------------------------
@@ -53,14 +61,13 @@ import java.util.*;
  * <p>
  * And finally, if we have class definitions in the classpath, we may choose to work with deserialized
- * typed objects at all times. In this case we do incur the deserialization cost, however,
- * Ignite will only deserialize on the first access and will cache the deserialized object,
- * so it does not have to be deserialized again:
+ * typed objects at all times. In this case we do incur the deserialization cost. However, if
+ * {@link PortableMarshaller#isKeepDeserialized()} is {@code true} then Ignite will only deserialize on the first access
+ * and will cache the deserialized object, so it does not have to be deserialized again:
  * <pre name=code class=java>